## Hook method to return entry id, generated from title or something
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=Hook method to return entry id, generated from title or something
##

# Write some code for entry id generation.
# You need simply return string id

# Return 'None' not to use this mechanis

return None
